@@ -1,4 +1,6 @@
-"""## Python SQL parser, transpiler and optimizer."""
+"""
+.. include:: ../README.md
+"""
 
 from __future__ import annotations
 
@@ -30,7 +32,7 @@ from sqlglot.parser import Parser
 from sqlglot.schema import MappingSchema
 from sqlglot.tokens import Tokenizer, TokenType
 
-__version__ = "10.2.9"
+__version__ = "10.2.11"
 
 pretty = False
 
