@@ -34,18 +34,6 @@ def _date_add_sql(kind):
     return func
 
 
-def _lateral_sql(self, expression):
-    this = self.sql(expression, "this")
-    if isinstance(expression.this, exp.Subquery):
-        return f"LATERAL{self.sep()}{this}"
-    alias = expression.args["alias"]
-    table = alias.name
-    table = f" {table}" if table else table
-    columns = self.expressions(alias, key="columns", flat=True)
-    columns = f" AS {columns}" if columns else ""
-    return f"LATERAL{self.sep()}{this}{table}{columns}"
-
-
 def _substring_sql(self, expression):
     this = self.sql(expression, "this")
     start = self.sql(expression, "start")
@@ -141,7 +129,7 @@ def _serial_to_generated(expression):
 
 def _to_timestamp(args):
     # TO_TIMESTAMP accepts either a single double argument or (text, text)
-    if len(args) == 1 and args[0].is_number:
+    if len(args) == 1:
         # https://www.postgresql.org/docs/current/functions-datetime.html#FUNCTIONS-DATETIME-TABLE
         return exp.UnixToTime.from_arg_list(args)
     # https://www.postgresql.org/docs/current/functions-formatting.html
@@ -216,6 +204,7 @@ class Postgres(Dialect):
             "BEGIN TRANSACTION": TokenType.BEGIN,
             "BIGSERIAL": TokenType.BIGSERIAL,
             "BY DEFAULT": TokenType.BY_DEFAULT,
+            "CHARACTER VARYING": TokenType.VARCHAR,
             "COMMENT ON": TokenType.COMMAND,
             "DECLARE": TokenType.COMMAND,
             "DO": TokenType.COMMAND,
@@ -246,14 +235,14 @@ class Postgres(Dialect):
         STRICT_CAST = False
 
         FUNCTIONS = {
-            **parser.Parser.FUNCTIONS,
+            **parser.Parser.FUNCTIONS,  # type: ignore
             "TO_TIMESTAMP": _to_timestamp,
             "TO_CHAR": format_time_lambda(exp.TimeToStr, "postgres"),
         }
 
     class Generator(generator.Generator):
         TYPE_MAPPING = {
-            **generator.Generator.TYPE_MAPPING,
+            **generator.Generator.TYPE_MAPPING,  # type: ignore
             exp.DataType.Type.TINYINT: "SMALLINT",
             exp.DataType.Type.FLOAT: "REAL",
             exp.DataType.Type.DOUBLE: "DOUBLE PRECISION",
@@ -263,7 +252,7 @@ class Postgres(Dialect):
         }
 
         TRANSFORMS = {
-            **generator.Generator.TRANSFORMS,
+            **generator.Generator.TRANSFORMS,  # type: ignore
             exp.ColumnDef: preprocess(
                 [
                     _auto_increment_to_serial,
@@ -279,7 +268,6 @@ class Postgres(Dialect):
             exp.CurrentTimestamp: lambda *_: "CURRENT_TIMESTAMP",
             exp.DateAdd: _date_add_sql("+"),
             exp.DateSub: _date_add_sql("-"),
-            exp.Lateral: _lateral_sql,
             exp.StrPosition: str_position_sql,
             exp.StrToTime: lambda self, e: f"TO_TIMESTAMP({self.sql(e, 'this')}, {self.format_time(e)})",
             exp.Substring: _substring_sql,
