@@ -48,6 +48,10 @@ class TokenType(AutoName):
     DOLLAR = auto()
     PARAMETER = auto()
     SESSION_PARAMETER = auto()
+    NATIONAL = auto()
+
+    BLOCK_START = auto()
+    BLOCK_END = auto()
 
     SPACE = auto()
     BREAK = auto()
@@ -108,6 +112,7 @@ class TokenType(AutoName):
 
     # keywords
     ALIAS = auto()
+    ALTER = auto()
     ALWAYS = auto()
     ALL = auto()
     ANTI = auto()
@@ -343,7 +348,11 @@ class _Tokenizer(type):
     def __new__(cls, clsname, bases, attrs):  # type: ignore
         klass = super().__new__(cls, clsname, bases, attrs)
 
-        klass._QUOTES = cls._delimeter_list_to_dict(klass.QUOTES)
+        klass._QUOTES = {
+            f"{prefix}{s}": e
+            for s, e in cls._delimeter_list_to_dict(klass.QUOTES).items()
+            for prefix in (("",) if s[0].isalpha() else ("", "n", "N"))
+        }
         klass._BIT_STRINGS = cls._delimeter_list_to_dict(klass.BIT_STRINGS)
         klass._HEX_STRINGS = cls._delimeter_list_to_dict(klass.HEX_STRINGS)
         klass._BYTE_STRINGS = cls._delimeter_list_to_dict(klass.BYTE_STRINGS)
@@ -422,6 +431,16 @@ class Tokenizer(metaclass=_Tokenizer):
     ESCAPES = ["'"]
 
     KEYWORDS = {
+        **{
+            f"{key}{postfix}": TokenType.BLOCK_START
+            for key in ("{{", "{%", "{#")
+            for postfix in ("", "+", "-")
+        },
+        **{
+            f"{prefix}{key}": TokenType.BLOCK_END
+            for key in ("}}", "%}", "#}")
+            for prefix in ("", "+", "-")
+        },
         "/*+": TokenType.HINT,
         "==": TokenType.EQ,
         "::": TokenType.DCOLON,
@@ -457,6 +476,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "CHECK": TokenType.CHECK,
         "CLUSTER BY": TokenType.CLUSTER_BY,
         "COLLATE": TokenType.COLLATE,
+        "COLUMN": TokenType.COLUMN,
         "COMMENT": TokenType.SCHEMA_COMMENT,
         "COMMIT": TokenType.COMMIT,
         "COMPOUND": TokenType.COMPOUND,
@@ -654,7 +674,16 @@ class Tokenizer(metaclass=_Tokenizer):
         "UNIQUE": TokenType.UNIQUE,
         "STRUCT": TokenType.STRUCT,
         "VARIANT": TokenType.VARIANT,
-        "ALTER": TokenType.COMMAND,
+        "ALTER": TokenType.ALTER,
+        "ALTER AGGREGATE": TokenType.COMMAND,
+        "ALTER DEFAULT": TokenType.COMMAND,
+        "ALTER DOMAIN": TokenType.COMMAND,
+        "ALTER ROLE": TokenType.COMMAND,
+        "ALTER RULE": TokenType.COMMAND,
+        "ALTER SEQUENCE": TokenType.COMMAND,
+        "ALTER TYPE": TokenType.COMMAND,
+        "ALTER USER": TokenType.COMMAND,
+        "ALTER VIEW": TokenType.COMMAND,
         "ANALYZE": TokenType.COMMAND,
         "CALL": TokenType.COMMAND,
         "EXPLAIN": TokenType.COMMAND,
@@ -954,7 +983,7 @@ class Tokenizer(metaclass=_Tokenizer):
         text = self._extract_string(quote_end)
         text = text.encode(self.ENCODE).decode(self.ENCODE) if self.ENCODE else text  # type: ignore
         text = text.replace("\\\\", "\\") if self._replace_backslash else text
-        self._add(TokenType.STRING, text)
+        self._add(TokenType.NATIONAL if quote[0].upper() == "N" else TokenType.STRING, text)
         return True
 
     # X'1234, b'0110', E'\\\\\' etc.
